@@ -6,6 +6,7 @@
 #python setup.py sdist
 #twine upload --repository-url https://upload.pypi.org/legacy/ dist/*
 
+#github actions - https://docs.github.com/en/actions/reference/workflow-commands-for-github-actions#setting-an-environment-variable
 
 from urllib.parse import quote
 import os
@@ -88,6 +89,9 @@ azure_variable = "testtorun"
 pipeoutput = "false"
 bitrise = "false"
 recursive = "false"
+executioncommand = ""
+printcommand = ""
+githubactionsvariable = ""
 
 def find(name):
     currentdir = os.getcwd() # using current dir, could change this to work with full computer search
@@ -319,6 +323,7 @@ def echo(stringtoprint):
     print (stringtoprint)
 
 def runcommand(command, stream="false"):
+    print("Running command "+ command)
     print("platform = " + sys.platform)
     if stream == "true":
         process = subprocess.Popen(command, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True, encoding='utf-8')
@@ -694,7 +699,7 @@ def runtestswithappsurify(*args):
     global fullnameseparator, fullname, failfast, maxrerun, rerun, importtype, reporttype, teststorun, deletereports, startrunall, endrunall, startrunspecific, endrunspecific
     global commit, scriptlocation, branch, runfrequency, fromcommit, repository, scriptlocation, generatefile, template, addtestsuitename, addclassname, runtemplate, testsuitesnameseparator
     global testtemplate, classnameseparator, testseparatorend, testtemplatearg1, testtemplatearg2, testtemplatearg3, testtemplatearg4, startrunpostfix, endrunprefix
-    global endrunpostfix, executetests, encodetests, testsuiteencoded, projectencoded, testsrun, trainer, azure_variable, pipeoutput, recursive, bitrise
+    global endrunpostfix, executetests, encodetests, testsuiteencoded, projectencoded, testsrun, trainer, azure_variable, pipeoutput, recursive, bitrise, executioncommand, githubactionsvariable, printcommand
 
     tests=""
     testsrun=""
@@ -757,6 +762,9 @@ def runtestswithappsurify(*args):
     pipeoutput = "false"
     bitrise = "false"
     recursive = "false"
+    executioncommand = ""
+    githubactionsvariable = ""
+    printcommand = ""
     #--testsuitesnameseparator and classnameseparator need to be encoded i.e. # is %23
 
 
@@ -819,7 +827,6 @@ def runtestswithappsurify(*args):
         teststorun="none"
         fail="newdefects, reopeneddefects, failedtests, brokentests"
         
-
     if runtemplate == "all tests":
         teststorun="all"
         fail="newdefects, reopeneddefects, failedtests, brokentests"
@@ -1272,9 +1279,20 @@ def runtestswithappsurify(*args):
                 bitrise = "true"
             if argv[k] == "--recursive":
                 recursive = "true"
+            if argv[k] == "--githubactionsvariable":
+                githubactionsvariable = argv[k+1]
+            if argv[k] == "--executioncommand":
+                executioncommand = argv[k+1]
+            if argv[k] == "--printcommand":
+                printcommand = argv[k+1]
+            printcommand
             if argv[k] == "--help":
                 echo("please see url for more details on this script and how to execute your tests with appsurify - https://github.com/Appsurify/AppsurifyCI")
 
+    if githubactionsvariable != "" and githubactionsvariable is not None:
+        executioncommand = "echo \"{githubactionsvariable}={[[teststorun]]}\" >> $GITHUB_ENV"
+        printcommand = "\"{githubactionsvariable}={[[teststorun]]}\" >> $GITHUB_ENV"
+    
     if "http://" in proxy:
         proxy = proxy.replace("http://","")
 
@@ -1425,6 +1443,40 @@ def runtestswithappsurify(*args):
         print (f'##vso[task.setvariable variable={azure_variable}{variable_num}]{testsrun}')
     #print("##vso[task.setvariable variable=BuildVersion;]998")
 
+    print("Execution command = " + executioncommand)
+
+    if executioncommand != "" and executioncommand is not None:
+        
+        #max_length = 28000
+        #variable_num = 1
+        #while len(testsrun) > max_length:
+        #    split_string = testsrun.find("|Name=",max_length)
+        #    setval = testsrun[:split_string]
+        #    testsrun = testsrun[split_string:]
+        #    print (f'##vso[task.setvariable variable={azure_variable}{variable_num}]{setval}')
+        #    variable_num = variable_num + 1
+        #print (f'##vso[task.setvariable variable={azure_variable}{variable_num}]{testsrun}')
+        executioncommand = executioncommand.replace("[[teststorun]]", testsrun)
+        print("Execution command is "+ executioncommand)
+        runcommand(executioncommand, True)
+
+    if printcommand != "" and printcommand is not None:
+        
+        #max_length = 28000
+        #variable_num = 1
+        #while len(testsrun) > max_length:
+        #    split_string = testsrun.find("|Name=",max_length)
+        #    setval = testsrun[:split_string]
+        #    testsrun = testsrun[split_string:]
+        #    print (f'##vso[task.setvariable variable={azure_variable}{variable_num}]{setval}')
+        #    variable_num = variable_num + 1
+        #print (f'##vso[task.setvariable variable={azure_variable}{variable_num}]{testsrun}')
+        printcommand = printcommand.replace("[[teststorun]]", testsrun)
+        print(printcommand)
+
+    #if githubactionsvariable != "" and githubactionsvariable is not None:
+    #    executioncommand = "echo \"\{githubactionsvariable\}={[[teststorun]]}\" >> $GITHUB_ENV"
+
     if bitrise == "true":
         print (f'envman add --key TESTS_TO_RUN --value \"{testsrun}\"')
 
